aboutsummaryrefslogtreecommitdiff
path: root/CST116-BlankConsole/CST116-BlankConsole.cpp
diff options
context:
space:
mode:
authorJoe Traver <[email protected]>2022-10-17 19:33:49 -0700
committerJoe Traver <[email protected]>2022-10-17 19:33:49 -0700
commita31ddd233ada8f9589d5c06e82448323e009cc3a (patch)
treea9c906cfcd3dff7b397233e36007d2b069b6407a /CST116-BlankConsole/CST116-BlankConsole.cpp
parentAdded Header and established named areas (diff)
downloadcst116-lab0-joetraver30-a31ddd233ada8f9589d5c06e82448323e009cc3a.tar.xz
cst116-lab0-joetraver30-a31ddd233ada8f9589d5c06e82448323e009cc3a.zip
removed std before cout and replaced /n with endl
added name and github ID as a cout command
Diffstat (limited to 'CST116-BlankConsole/CST116-BlankConsole.cpp')
-rw-r--r--CST116-BlankConsole/CST116-BlankConsole.cpp23
1 files changed, 20 insertions, 3 deletions
diff --git a/CST116-BlankConsole/CST116-BlankConsole.cpp b/CST116-BlankConsole/CST116-BlankConsole.cpp
index f52b208..b13a366 100644
--- a/CST116-BlankConsole/CST116-BlankConsole.cpp
+++ b/CST116-BlankConsole/CST116-BlankConsole.cpp
@@ -1,13 +1,30 @@
-// CST116-BlankConsole.cpp : This file contains the 'main' function. Program execution begins and ends there.
-//
+// CST116-Lab0-Traver.cpp : This file contains the 'main' function. Program execution begins and ends there.
+//
+// Joe Traver
+// CST-116
+// Lab0
+// Intro Lab
+
#include <iostream>
+using std::cout
+using std::endl
+
+
int main()
{
- std::cout << "Hello World!\n";
+ cout << "Hello World!" endl;
+
+ cout << "Joe Traver" endl;
+ cout << "GitHud ID - joetraver30" endl:
+
+
+
}
+
+
// Run program: Ctrl + F5 or Debug > Start Without Debugging menu
// Debug program: F5 or Debug > Start Debugging menu